@@ -17,7 +17,7 @@ $Profiles->{'DE-BY-noris'} = {    # noris Kalender
     %{ $Profiles->{'DE-BY'} },    # Bayern
     "Nikolaus"          => "#06.12.",
     "Heiligabend"       => ":24.12.",
-    "Sylvester"         => ":31.12.",
+    "Silvester"         => ":31.12.",
     "Mari\xE4 Himmelfahrt" => "#15.08.",
 };
 
